@@ -6,7 +6,7 @@
 ;;         Jun'ichi Shiono  <jun@fsas.fujitsu.com>
 ;;         Yasutaka SHINDOH <ring-pub@fan.gr.jp>
 ;; Created: 2001/06/28
-;; Revised: 2005/03/04
+;; Revised: 2005/05/13
 ;; Keywords: font-lock emacs-lisp change-log texinfo c java perl html
 ;;           mail news
 
@@ -209,7 +209,7 @@
 
 ;;; Code:
 
-(defconst develock-version "0.25"
+(defconst develock-version "0.26"
   "Version number for this version of Develock.")
 
 (require 'advice)
@@ -1163,7 +1163,15 @@ Energize font-lock keywords for extraordinary level highlighting."
       (if (and (stringp def)
 	       (string-match "^\\^\\((\\\\(def\\)" def))
 	  (setcar (car lisp-font-lock-keywords-1)
-		  (replace-match "^[\t ]*\\1" nil nil def)))))
+		  (replace-match "^[\t ]*\\1" nil nil def))))
+  (defadvice font-lock-add-keywords (around inhibit-develock activate)
+    "Run `font-lock-set-defaults' being not advised by Develock."
+    (let ((develock-inhibit-advice-font-lock-set-defaults t))
+      ad-do-it))
+  (defadvice font-lock-remove-keywords (around inhibit-develock activate)
+    "Run `font-lock-set-defaults' being not advised by Develock."
+    (let ((develock-inhibit-advice-font-lock-set-defaults t))
+      ad-do-it)))
 
 (defmacro develock-max-column ()
   "Return the maximum column number from which lines won't be highlighted."
